==> bus-all-8.1.0-sources.jar: org/miaixz/bus/image/galaxy/dict/GEMS_ACRQA_1_0_BLOCK3/PrivateTag.java <==
/*
 ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~
 ~                                                                               ~
 ~ The MIT License (MIT)                                                         ~
 ~                                                                               ~
 ~ Copyright (c) 2015-2024 miaixz.org and other contributors.                    ~
 ~                                                                               ~
 ~ Permission is hereby granted, free of charge, to any person obtaining a copy  ~
 ~ of this software and associated documentation files (the "Software"), to deal ~
 ~ in the Software without restriction, including without limitation the rights  ~
 ~ to use, copy, modify, merge, publish, distribute, sublicense, and/or sell     ~
 ~ copies of the Software, and to permit persons to whom the Software is         ~
 ~ furnished to do so, subject to the following conditions:                      ~
 ~                                                                               ~
 ~ The above copyright notice and this permission notice shall be included in    ~
 ~ all copies or substantial portions of the Software.                           ~
 ~                                                                               ~
 ~ THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR    ~
 ~ IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,      ~
 ~ FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE   ~
 ~ AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER        ~
 ~ LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, ~
 ~ OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN     ~
 ~ THE SOFTWARE.                                                                 ~
 ~                                                                               ~
 ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~
*/
package org.miaixz.bus.image.galaxy.dict.GEMS_ACRQA_1_0_BLOCK3;

/**
 * @author Kimi Liu
 * @since Java 17+
 */
public class PrivateTag {

    public static final String PrivateCreator = "GEMS_ACRQA_1.0 BLOCK3";

    /** (0023,xx00) VR=DS VM=1 CR DRE */
    public static final int CRDRE = 0x00230000;

    /** (0023,xx10) VR=US VM=1 CR DRN */
    public static final int CRDRN = 0x00230010;

    /** (0023,xx20) VR=DS VM=1 CR ORE */
    public static final int CRORE = 0x00230020;

    /** (0023,xx30) VR=US VM=1 CR ORN */
    public static final int CRORN = 0x00230030;

    /** (0023,xx40) VR=US VM=1 CR ORD */
    public static final int CRORD = 0x00230040;

    /** (0023,xx50) VR=LO VM=1 CR Cassette Size */
    public static final int CRCassetteSize = 0x00230050;

    /** (0023,xx60) VR=LO VM=1 CR Machine ID */
    public static final int CRMachineID = 0x00230060;

    /** (0023,xx70) VR=LO VM=1 CR Machine Type */
    public static final int CRMachineType = 0x00230070;

    /** (0023,xx80) VR=LO VM=1 CR Technician Code */
    public static final int CRTechnicianCode = 0x00230080;

    /** (0023,xx90) VR=LO VM=1 CR Energy Subtraction Parameters */
    public static final int CREnergySubtractionParameters = 0x00230090;

}

==> bus-all-8.1.5-sources.jar: org/miaixz/bus/image/galaxy/dict/GEMS_ACRQA_2_0_BLOCK3/PrivateTag.java <==
/*
 ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~
 ~                                                                               ~
 ~ The MIT License (MIT)                                                         ~
 ~                                                                               ~
 ~ Copyright (c) 2015-2025 miaixz.org and other contributors.                    ~
 ~                                                                               ~
 ~ Permission is hereby granted, free of charge, to any person obtaining a copy  ~
 ~ of this software and associated documentation files (the "Software"), to deal ~
 ~ in the Software without restriction, including without limitation the rights  ~
 ~ to use, copy, modify, merge, publish, distribute, sublicense, and/or sell     ~
 ~ copies of the Software, and to permit persons to whom the Software is         ~
 ~ furnished to do so, subject to the following conditions:                      ~
 ~                                                                               ~
 ~ The above copyright notice and this permission notice shall be included in    ~
 ~ all copies or substantial portions of the Software.                           ~
 ~                                                                               ~
 ~ THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR    ~
 ~ IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,      ~
 ~ FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE   ~
 ~ AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER        ~
 ~ LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, ~
 ~ OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN     ~
 ~ THE SOFTWARE.                                                                 ~
 ~                                                                               ~
 ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~ ~
*/
package org.miaixz.bus.image.galaxy.dict.GEMS_ACRQA_2_0_BLOCK3;

/**
 * @author Kimi Liu
 * @since Java 17+
 */
public class PrivateTag {

    public static final String PrivateCreator = "GEMS_ACRQA_2.0 BLOCK3";

    /** (0023,xx00) VR=DS VM=1 CR DRE */
    public static final int CRDRE = 0x00230000;

    /** (0023,xx10) VR=US VM=1 CR DRN */
    public static final int CRDRN = 0x00230010;

    /** (0023,xx20) VR=DS VM=1 CR ORE */
    public static final int CRORE = 0x00230020;

    /** (0023,xx30) VR=US VM=1 CR ORN */
    public static final int CRORN = 0x00230030;

    /** (0023,xx40) VR=US VM=1 CR ORD */
    public static final int CRORD = 0x00230040;

    /** (0023,xx50) VR=LO VM=1 CR Cassette Size */
    public static final int CRCassetteSize = 0x00230050;

    /** (0023,xx60) VR=LO VM=1 CR Machine ID */
    public static final int CRMachineID = 0x00230060;

    /** (0023,xx70) VR=LO VM=1 CR Machine Type */
    public static final int CRMachineType = 0x00230070;

    /** (0023,xx80) VR=LO VM=1 CR Technician Code */
    public static final int CRTechnicianCode = 0x00230080;

    /** (0023,xx90) VR=LO VM=1 CR Energy Subtraction Parameters */
    public static final int CREnergySubtractionParameters = 0x00230090;

    /** (0023,xxF0) VR=LO VM=1 CR Distribution Code */
    public static final int CRDistributionCode = 0x002300F0;

    /** (0023,xxFF) VR=US VM=1 CR Shutters Applied */
    public static final int CRShuttersApplied = 0x002300FF;

}
